@@ -7,9 +7,14 @@ Tool for downloading Spotify songs to MP3 - Full Metadata & Cover Art
 :License: MIT (see /LICENSE).
 """
 
+from .savify import *
+from .types import *
+
 __title__ = 'Savify'
 __author__ = """Laurence Rawlings"""
 __email__ = 'contact@laurencerawlings.com'
-__version__ = '1.1.0'
+__version__ = '1.1.1'
 __license__ = 'MIT'
 __docformat__ = 'restructuredtext en'
+
+__all__ = ['savify', 'types']
